@@ -1,12 +1,11 @@
-"""
-This module includes instruments to analyze, what are the drivers of returns of a portfolio. It can
+"""This module includes tools to analyze, what are the drivers of returns of a portfolio. It can
 be used to identify, whether excess returns are achieved by skills of portfolio managing or simply
-by exposure on some factors.
+by exposure on some factors. This also can help to more accurately understand the startegy itself and
+its differences from simple investing into a factor.
 """
 
 import pandas as pd
-from statsmodels.regression.linear_model import OLS
-from statsmodels.tools.tools import add_constant
+from statsmodels.api import OLS, add_constant
 
 from .utils import get_annualization_factor, align
 
@@ -39,8 +38,7 @@ def explain_alpha(returns, market_returns, factors_returns, risk_free_rate=0):
     factors_returns = pd.DataFrame([adjusted_market_returns] + factors_returns).T
     factors_returns = add_constant(factors_returns)
 
-    y, x = align(adjusted_returns, factors_returns)
-    est = OLS(y, x).fit()
+    est = OLS(adjusted_returns, adjusted_market_returns).fit()
     params = est.params.values
     params[0] *= get_annualization_factor(returns)
 
