@@ -1,5 +1,4 @@
-"""
-This module contains all necessary functionality to create factor models. Factor model is the set of
+"""This module contains all necessary instruments to create factor models. Factor model is the set of
 portfolios, covering all stock universe in each period. It is used to test whether any factor is
 present on the market or not, that is why full coverage of stock universe is important.
 
@@ -17,19 +16,16 @@ grid_search() function.
 import numpy as np
 import pandas as pd
 
-from .portfolios import Portfolio
 from .factors import Factor
-from .metrics import summary
-from .plotting import plot_cumulative_returns
+from .portfolios import Portfolio
 
 __all__ = [
     'fit_factor_model',
-    'factor_model_tear_sheet',
     'grid_search',
 ]
 
 
-def fit_factor_model(stock_prices, factor, is_bigger_better=True, weighting_factor=None, 
+def fit_factor_model(stock_prices, factor, better='less', weighting_factor=None, 
                      balance=None, fee_rate=0, quantiles=3, add_wml=False):
     """Fits factor model with quantile-method.
 
@@ -41,7 +37,7 @@ def fit_factor_model(stock_prices, factor, is_bigger_better=True, weighting_fact
         Prices, representing stock universe.
     factor : Factor
         Factor to pick stocks into the portfolio.
-    is_bigger_better : bool, default=True
+    better: {'more', 'less'}, default='more'
         Whether bigger values of factor are treated as better to pick or in contrary as better to 
         avoid. 
     weighting_factor : Factor, optional
@@ -66,7 +62,7 @@ def fit_factor_model(stock_prices, factor, is_bigger_better=True, weighting_fact
     portfolios = []
     for q in quantiles_:
         portfolio = Portfolio('q({:.2f}, {:.2f})'.format(*q))
-        portfolio.pick_by_factor(factor, q, is_bigger_better, method='quantile')
+        portfolio.pick_by_factor(factor, q, better, method='quantile')
         if weighting_factor is not None:
             portfolio.weigh_by_factor(factor)
         else:
@@ -89,50 +85,24 @@ def fit_factor_model(stock_prices, factor, is_bigger_better=True, weighting_fact
     return portfolios
 
 
-def factor_model_tear_sheet(portfolios, benchmark):
-    """Shows the performance assessment of a factor model' portfolios.
-
-    For now:
-
-    * shows summary stats table
-    * plots cumulative returns
-
-    Parameters
-    ----------
-    portfolios : sequence of Portfolio
-        Portfolios, included into the factor model.
-    benchmark : Portfolio or Benchmark
-        Benchmark to compute some metrics.
-
-    Returns
-    -------
-    pd.DataFrame
-        Table with summary stats.
-    """
-
-    stats = pd.DataFrame([summary(p, benchmark) for p in portfolios]).T.round(2)
-    plot_cumulative_returns(portfolios, benchmark)
-    return stats
-
-
-def grid_search(stock_prices, factor_data, params, target_metric, method='static', mask=None, **kwargs):
+def grid_search(stock_prices, factor_data, params, target_metric, approach='static', mask=None, **kwargs):
     """Fits a grid of factor models.
 
-    Can be used to find the best parameters or just as fast alias to build a
-    lot of models with different parameters.
+    Can be used to find the best parameters or just as fast alias to build a lot of models with different 
+    parameters.
 
     Parameters
     ----------
     stock_prices : pd.DataFrame
         Prices, representing stock universe.
     factor_data : pd.DataFrame
-        Factor, used to pick stocks from (filtered) stock universe.
+        Factor values, used to pick stocks from (filtered) stock universe.
     params : sequence of tuple of int
         Parameters to iterate over `factor_data` to make it a factor.
     target_metric : callable
         Function-like object, computing some metric (e.g. value of metric). It must get as input 
         portfolio returns and return as output a number - value of the metric.
-    method : {'static', 'dynamic'}, default='static'
+    approach : {'static', 'dynamic'}, default='static'
         Whether absolute values of `factor` are used to make decision or their percentage changes.
     mask : pd.DataFrame, optional
         Matrix of True/False, where True means that a value should remain in `factor` and False - 
@@ -150,7 +120,7 @@ def grid_search(stock_prices, factor_data, params, target_metric, method='static
     metric_rows = []
     for looking, lag, holding in params:
         factor = Factor(factor_data)
-        factor.look_back(looking, method).lag(lag).hold(holding)
+        factor.look_back(looking, approach).lag(lag).hold(holding)
         if mask is not None:
             factor.filter(mask)
         portfolios = fit_factor_model(stock_prices, factor, **kwargs)
