@@ -1,5 +1,4 @@
-"""
-This module contains stuff to work with factors data. Factors are drivers of returns on the stock
+"""This module contains stuff to work with factors data. Factors are drivers of returns on the stock
 (and any other) market, explaining the risks of investing into assets. We assume that a factor can
 be presented by simple table (pandas DataFrame), where each row represents a timestamp, each
 column - a stock (ticker) and each cell - value of the factor for the stock in the timestamp.
@@ -45,22 +44,22 @@ class Factor:
     def __init__(self, data):
         self.data = data.copy()
 
-    def look_back(self, period=1, method='static'):
+    def look_back(self, period=1, approach='static'):
         """Looks back on `factor` for `period` periods.
 
-        If `method` is dynamic:
+        If `approach` is dynamic:
             calculates percentage changes with looking back by `period` periods, then values are
             lagged for 1 period (because in period t(0) we can know percentage change from period
             t(-looking_period) only at the end of t(0), so it is needed to avoid look-ahead bias).
 
-        If `method` is static:
+        If `approach` is static:
             all values are shifted for `period`.
 
         Parameters
         ----------
         period : int > 0, default=1
             Looking back period for `factor`.
-        method : {'static', 'dynamic'}, default='static'
+        approach : {'static', 'dynamic'}, default='static'
             Whether absolute values of `factor` are used to make decision or their percentage
             changes.
 
@@ -70,10 +69,10 @@ class Factor:
             Factor with transformed data.
         """
 
-        if method == 'dynamic':
+        if approach == 'dynamic':
             self.data = self.data.pct_change(period)
             self.lag(1)
-        else:  # method = 'static'
+        else:  # approach = 'static'
             self.data = self.data.shift(period)
 
         self.data = self.data.iloc[period:]
@@ -150,7 +149,100 @@ class Factor:
         """
 
         self.data, mask = align(self.data, mask)
-
         self.data[~mask] = np.nan
 
         return self
+
+    def __eq__(self, other):
+        if isinstance(other, Factor):
+            return self.data == other.data
+        return self.data == other
+
+    def __ne__(self, other):
+        if isinstance(other, Factor):
+            return self.data != other.data
+        return self.data != other
+
+    def __lt__(self, other):
+        if isinstance(other, Factor):
+            return self.data < other.data
+        return self.data < other
+
+    def __gt__(self, other):
+        if isinstance(other, Factor):
+            return self.data > other.data
+        return self.data > other
+    
+    def __le__(self, other):
+        if isinstance(other, Factor):
+            return self.data <= other.data
+        return self.data <= other
+    
+    def __ge__(self, other):
+        if isinstance(other, Factor):
+            return self.data >= other.data
+        return self.data >= other
+
+    def __add__(self, other):
+        if isinstance(other, Factor):
+            return Factor(self.data + other.data)
+        return Factor(self.data + other)
+
+    __radd__ = __add__
+
+    def __sub__(self, other):
+        if isinstance(other, Factor):
+            return Factor(self.data - other.data)
+        return Factor(self.data - other)
+
+    def __rsub__(self, other):
+        if isinstance(other, Factor):
+            return Factor(other.data - self.data)
+        return Factor(other - self.data)
+    
+    def __mul__(self, other):
+        if isinstance(other, Factor):
+            return Factor(self.data * other.data)
+        return Factor(self.data * other)
+
+    __rmul__ = __mul__
+
+    def __floordiv__(self, other):
+        if isinstance(other, Factor):
+            return Factor(self.data // other.data)
+        return Factor(self.data // other)
+
+    def __rfloordiv__(self, other):
+        if isinstance(other, Factor):
+            return Factor(other.data // self.data)
+        return Factor(other // self.data)
+    
+    def __truediv__(self, other):
+        if isinstance(other, Factor):
+            return Factor(self.data / other.data)
+        return Factor(self.data / other)
+
+    def __rtruediv__(self, other):
+        if isinstance(other, Factor):
+            return Factor(other.data / self.data)
+        return Factor(other / self.data)
+
+    def __mod__(self, other):
+        if isinstance(other, Factor):
+            return Factor(self.data % other.data)
+        return Factor(self.data % other)
+
+    def __rmod__(self, other):
+        if isinstance(other, Factor):
+            return Factor(other.data % self.data)
+        return Factor(other % self.data)
+    
+    def __pow__(self, other):
+        if isinstance(other, Factor):
+            return Factor(self.data ** other.data)
+        return Factor(self.data ** other)
+
+    def __rpow__(self, other):
+        if isinstance(other, Factor):
+            return Factor(other.data ** self.data)
+        return Factor(other ** self.data)
