@@ -1,5 +1,4 @@
-"""
-This module contains metrics and statistics to assess performance of a portfolio. Usual metrics are
+"""This module contains metrics and statistics to assess performance of a portfolio. Usual metrics are
 always numbers (int or float), but also rolling metrics are supported. Rolling metrics by default
 are calculated to estimate annual performance of a portfolio in each trading period: every period
 gather not all points of returns but only for 1 year (e.g. if returns are monthly, rolling window
@@ -11,8 +10,7 @@ you are welcome to create your own metrics and to contribute to source code.
 
 import numpy as np
 import pandas as pd
-from statsmodels.regression.linear_model import OLS
-from statsmodels.tools.tools import add_constant
+from statsmodels.api import OLS, add_constant
 from scipy.stats import ttest_1samp
 
 from .utils import get_annualization_factor, align
@@ -77,6 +75,7 @@ def summary(portfolio, benchmark):
     Returns
     -------
     pd.Series
+        Series with index, representing metrics and values - values of the metrics.
     """
 
     return pd.Series(
