@@ -1,5 +1,4 @@
-"""
-This module contains stuff to create portfolios of stocks. Portfolio is a rebalancing each period
+"""This module contains tools to create portfolios of stocks. Portfolio is a rebalancing each period
 batch of stocks. So, portfolio can be represented as matrix with zeros on cells, where a stock is
 not picked, and weights (or lots) on cells, where a stock is picked into a portfolio.
 
@@ -86,7 +85,7 @@ class Portfolio:
 
         return self
 
-    def pick_by_factor(self, factor, thresholds, is_bigger_better=True, method='quantile'):
+    def pick_by_factor(self, factor, thresholds, better='more', method='quantile'):
         """Picks subset of stocks into the portfolio, choosing them by `factor`.
 
         Supports 3 methods to pick stocks:
@@ -101,7 +100,7 @@ class Portfolio:
             Factor to pick stocks into the portfolio.
         thresholds : tuple of int or float
             Bounds for the set of allowed values of `factor` to pick stocks.
-        is_bigger_better: bool, default=True
+        better: {'more', 'less'}, default='more'
             Whether bigger values of factor are treated as better to pick or in contrary as better to 
             avoid. 
         method : {'quantile', 'top', 'time-series'}, default='quantile'
@@ -114,28 +113,31 @@ class Portfolio:
         """
 
         if method == 'quantile':
-            if is_bigger_better:
+            if better == 'more':
                 thresholds = (1 - thresholds[1], 1 - thresholds[0])
 
             lower_threshold, upper_threshold = np.nanquantile(
                 factor.data, thresholds, axis=1, keepdims=True
             )
         elif method == 'top':
-            if is_bigger_better:
-                top_func = pd.Series.nlargest
-                bound_func = np.nanmin
-            else:
-                top_func = pd.Series.nsmallest
-                bound_func = np.nanmax
-
-            lower_threshold = bound_func(
-                factor.data.apply(top_func, n=thresholds[1], axis=1),
-                axis=1, keepdims=True
-            )
-            upper_threshold = bound_func(
-                factor.data.apply(top_func, n=thresholds[0], axis=1),
-                axis=1, keepdims=True
-            )
+            if better == 'more':
+                lower_threshold = np.nanmin(
+                    factor.data.apply(pd.Series.nlargest, n=thresholds[1], axis=1),
+                    axis=1, keepdims=True
+                )
+                upper_threshold = np.nanmin(
+                    factor.data.apply(pd.Series.nlargest, n=thresholds[0], axis=1),
+                    axis=1, keepdims=True
+                )
+            else:  # better == 'less'
+                lower_threshold = np.nanmax(
+                    factor.data.apply(pd.Series.nsmallest, n=thresholds[0], axis=1),
+                    axis=1, keepdims=True
+                )
+                upper_threshold = np.nanmax(
+                    factor.data.apply(pd.Series.nsmallest, n=thresholds[1], axis=1),
+                    axis=1, keepdims=True
+                )
         else:  # method = 'time-series'
             lower_threshold, upper_threshold = thresholds
 
@@ -187,7 +189,7 @@ class Portfolio:
         if mask is not None:
             picks[~mask] = np.nan
 
-        def random_pick(row: np.ndarray, indices=np.indices((picks.shape[1],))[0]):
+        def random_pick(row, indices=np.indices((picks.shape[1],))[0]):
             random_picks = np.zeros_like(row, dtype=int)
 
             long = (row == 1).sum()
@@ -206,6 +208,49 @@ class Portfolio:
 
         return self
 
+    def pick_ideally(self, stock_prices, portfolio, mask=None):
+        """Picks stocks ideally in the same quantity as in the `portfolio`.
+
+        In each period simply look forward to stock returns and long stocks with the best performance and
+        short stocks with the worst into an "ideal" portfolio.
+
+        Parameters
+        ----------
+        stock_prices : pd.DataFrame
+            Prices, representing stock universe.
+        portfolio : Portfolio
+            Portfolio to be replicated by "ideal" portfolio.
+        mask : pd.DataFrame, optional
+            Matrix of True/False, where True means that a stock can be picked in that period and
+            False - that a stock cannot be picked.
+
+        Returns
+        -------
+        Portfolio
+            Portfolio with filled picks.
+        """
+
+        stock_returns = stock_prices.pct_change().shift(-1)
+        if mask is not None:
+            stock_returns[~mask] = np.nan
+        stock_returns, picks = align(stock_returns, portfolio.picks)
+
+        ideal_picks = pd.DataFrame(np.zeros_like(picks), index=picks.index, columns=picks.columns)
+        for date in picks.index:
+            row = picks.loc[date]
+            returns = stock_returns.loc[date]
+
+            long = (row == 1).sum()
+            short = (row == -1).sum()
+            long_picks = returns.nlargest(long).index
+            short_picks = returns.nsmallest(short).index
+
+            ideal_picks.loc[date, long_picks] = 1
+            ideal_picks.loc[date, short_picks] = -1
+        
+        self.picks = ideal_picks
+
+        return self
 
     def filter(self, mask):
         """Filters `picks` by given `mask`.
@@ -275,10 +320,11 @@ class Portfolio:
 
         return self
 
-    def scale_by_factor(self, factor, target=1, leverage_limits=(-np.inf, np.inf)):
-        """Scale the `weights` by `target` of `factor`.
+    def scale_by_factor(self, factor, target=1, leverage_limits=(-np.inf, np.inf), better='more'):
+        """Scale `weights` by `target` of `factor`.
 
-        Simply divides each value in a row by `target`.
+        Simply divides each value in a row by `target` if `better` equals to 'more', otherwise `target` is
+        simply divided by a row of `factor` values.
 
         Parameters
         ----------
@@ -288,6 +334,8 @@ class Portfolio:
             Target of `factor`.
         leverage_limits : tuple of int or float, default=(-np.inf, np.inf)
             Thresholds to limit min and max leverage for positions weights.
+        better : {'more', 'less'}, default='less'
+            Whether exceeding the `target` will result in a higher leverage or a lower.
 
         Returns
         -------
@@ -301,14 +349,18 @@ class Portfolio:
 
         weights, factor_data = align(self.weights, factor.data)
 
-        weights = weights.multiply(factor_data / target, axis=0)
-        leverage = weights.sum(axis=1)
+        if better == 'more':
+            leverage = factor_data / target
+        else:
+            leverage = target / factor_data
+        weights = weights.multiply(leverage, axis=0)
 
+        total_leverage = weights.sum(axis=1)
         lower_limit, upper_limit = leverage_limits
-        exceed_lower = leverage < lower_limit
-        exceed_upper = leverage > upper_limit
-        weights[exceed_lower] = weights[exceed_lower].divide(leverage[exceed_lower] / lower_limit, axis=0)
-        weights[exceed_upper] = weights[exceed_upper].divide(leverage[exceed_upper] / upper_limit, axis=0)
+        exceed_lower = total_leverage < lower_limit
+        exceed_upper = total_leverage > upper_limit
+        weights[exceed_lower] = weights[exceed_lower].divide(total_leverage[exceed_lower] / lower_limit, axis=0)
+        weights[exceed_upper] = weights[exceed_upper].divide(total_leverage[exceed_upper] / upper_limit, axis=0)
 
         self.weights = weights.fillna(0)
 
@@ -337,11 +389,6 @@ class Portfolio:
         -------
         Portfolio
             Portfolio with filled positions and returns.
-
-        Notes
-        -----
-        For now allocation with money can lead to negative cash if `fee_rate` != 0, but it will be
-        fixed soon.
         """
 
         if balance is None:
